@@ -8,6 +8,8 @@
 #include <stdlib.h>
 #include <fcntl.h>
 
+extern int getfd(void);
+
 int
 main(int argc, char *argv[]) {
     int fd, num;
@@ -16,8 +18,7 @@ main(int argc, char *argv[]) {
 	fprintf(stderr, "usage: chvt N\n");
 	exit(1);
     }
-    if ((fd = open("/dev/console", 0)) < 0)
-      fd = 0;
+    fd = getfd();
     num = atoi(argv[1]);
     if (ioctl(fd,VT_ACTIVATE,num)) {
 	perror("VT_ACTIVATE");
