@@ -8,14 +8,14 @@
 #include <linux/kd.h>
 #include <sys/ioctl.h>
 
+extern int getfd(void);
+
 int
 main(int argc, char *argv[]) {
 	struct unimapinit advice;
 	int fd;
 
-	/* we do not want to read, but only need some fd */
-	if ((fd = open("/dev/console", 0)) < 0)
-	    fd = 0;
+	fd = getfd();
 
 	advice.advised_hashsize = 0;
 	advice.advised_hashstep = 0;
