@@ -8,6 +8,7 @@
 #include <linux/vt.h>
 #include <stdio.h>
 
+extern int getfd(void);
 char *progname;
 
 void
@@ -20,13 +21,12 @@ int
 main(int argc, char *argv[]) {
     int fd, num, i;
 
-    if ((fd = open("/dev/console", 0)) < 0)
-      fd = 0;
-
     if (argc < 1)		/* unlikely */
       exit(1);
     progname = argv[0];
 
+    fd = getfd();
+
     if (argc == 1) {
 	/* disallocate all unused consoles */
 	if (ioctl(fd,VT_DISALLOCATE,0)) {
