@@ -34,7 +34,8 @@
 #define MAX_NR_KEYMAPS NR_KEYMAPS
 #endif
 
-#define VERSION "0.89"
+#define VERSION "0.91"
+extern int getfd();
 static int fd;
 
 char keymap_exists[MAX_NR_KEYMAPS];
@@ -162,7 +163,7 @@ u_char maximum_val(int t) {
 	return i - 1;
 }
 
-#define NR_TYPES 12
+#define NR_TYPES 13
 int maxval[NR_TYPES];
 
 void show_short_info(void) {
@@ -490,10 +491,7 @@ main (int argc, char *argv[]) {
 	if (optind < argc)
 		usage();
 
-	if ((fd = open("/dev/console", O_RDONLY)) < 0) {
-		perror("when opening /dev/console");
-		exit(1);
-	}
+	fd = getfd();
 
 	if (short_info || long_info) {
 		show_short_info();
