@@ -1,6 +1,8 @@
 #include <stdio.h>
 #include <errno.h>
 #include <linux/kd.h>
+
+extern int getfd();
 extern char *malloc();
 
 main(){
@@ -8,9 +10,7 @@ main(){
     struct unimapdesc ud;
     int i;
 
-    fd = open("/dev/console", 0);
-    if (fd < 0)
-      fd = 0;
+    fd = getfd();
 
     ud.entry_ct = ct = 0;
     ud.entries = 0;
