@@ -12,13 +12,15 @@
 #include <fcntl.h>
 #include <linux/kd.h>
 #include <sys/ioctl.h>
-#include <malloc.h> /* just to be sure */
 #include "paths.h"
 
 /* the two exported functions */
 void saveunicodemap(int fd, char *oufil);
 void loadunicodemap(int fd, char *ufil);
 
+extern char *malloc(), *realloc();
+extern int getfd(void);
+
 static char *unidirpath[] = { "", DATADIR "/" TRANSDIR "/", 0 };
 static char *unisuffixes[] = { "", ".uni", 0 };
 
@@ -27,9 +29,7 @@ int
 main(int argc, char *argv[]) {
 	int fd;
 
-	/* we do not want to read, but only need some fd */
-	if ((fd = open("/dev/console", 0)) < 0)
-	    fd = 0;
+	fd = getfd();
 
 	if (argc >= 3 && !strcmp(argv[1], "-o")) {
 	    saveunicodemap(fd, argv[2]);
