@@ -85,6 +85,7 @@
 #define MODE_VGALINES		1
 
 extern char *index();
+extern int getfd();
 static void usage(void);
 
 /* VGA textmode register tweaking. */
@@ -138,9 +139,7 @@ main(argc, argv) int argc; char **argv; {
  	fclose(fin);
     }
 
-    /* we do not want to read, but only need some fd */
-    if ((fd = open("/dev/console", 0)) < 0)
-      fd = 0;
+    fd = getfd();
 
     if(ioctl(fd, TIOCGWINSZ, &winsize)) {
 	perror("TIOCGWINSZ");
