@@ -5,6 +5,9 @@
  */
 #include <stdio.h>
 #include <linux/termios.h>
+
+extern int getfd();
+
 main(int argc, char *argv[]) {
     int fd;
     struct { char ten, onoff; } arg;
@@ -13,8 +16,7 @@ main(int argc, char *argv[]) {
        fprintf(stderr, "usage: setvesablank ON|on|off\n");
        exit(1);
     }
-    if ((fd = open("/dev/console", 0)) < 0)
-      fd = 0;
+    fd = getfd();
     arg.ten = 10;
     arg.onoff = 0;
     if (!strcmp(argv[1], "on"))
